@@ -1,3 +1,5 @@
+# -*- coding: utf-8 -*-
+
 """
 onemapsg.exceptions
 ~~~~~~~~~~~~~~~~~~~
@@ -9,14 +11,11 @@ thrown from the API.
 
 class AuthenticationError(Exception):
     """Raised when client fails to authenticate with the server."""
-    pass
 
 
 class BadRequest(Exception):
     """Raised when status 40x is received as a response code."""
-    pass
 
 
 class ServerError(Exception):
     """Raised when there are server errors from OneMap SG."""
-    pass
